Learn R Programming

lsm (version 0.2.1.2)

confint.lsm: Confidence Intervals for lsm Objects

Description

Provides a confint method for lsm objects.

Usage

# S3 method for lsm
confint(object, parm, level = 0.95, ...)

Value

lsm returns an object of class "lsm".

An object of class "lsm" is a list containing at least the following components:

object

a lsm object

parm

parameter

level

confidence levels

...

additional parameters

Arguments

object

The type of prediction required. The default is on the scale of the linear predictors. The alternative response gives the predicted probabilities.

parm

further arguments passed to or from other methods.

level

The type of prediction required. The default is on the scale of the linear predictors. The alternative response gives the predicted probabilities.

...

further arguments passed to or from other methods.

Author

Jorge Villalba Acevedo [cre, aut], Cartagena-Colombia.

Details

confint Method for lsm

The saturated model is characterized by the assumptions 1 and 2 presented in section 2.3 by Llinas (2006, ISSN:2389-8976).

References

[1] Humberto Jesus Llinas. (2006). Accuracies in the theory of the logistic models. Revista Colombiana De Estadistica,29(2), 242-244.

[2] Hosmer, D. (2013). Wiley Series in Probability and Statistics Ser. : Applied Logistic Regression (3). New York: John Wiley & Sons, Incorporated.

[3] Chambers, J. M. and Hastie, T. J. (1992) Statistical Models in S. Wadsworth & Brooks/Cole.

Examples

Run this code
 #Hosmer, D. (2013) page 3: Age and coranary Heart Disease (CHD) Status of 20 subjects:
 #AGE <- c(20, 23, 24, 25, 25, 26, 26, 28, 28, 29, 30, 30, 30, 30, 30, 30, 30, 32, 33, 33)
 #CHD <- c(0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0)
 # data <- data.frame (CHD, AGE)
 # Ela <- lsm(CHD ~ AGE, family = binomial, data)
 # summary(Ela)

Run the code above in your browser using DataLab