lsm ObjectsObtains predictions from a fitted lsm object.
# S3 method for lsm
predict(
object,
newdata,
type = c("link", "response", "odd"),
interval = c("none", "confidence", "prediction", "odd"),
level = 0.95,
...
)A vector or matrix of predictions. following components:
A fitted object of class lsm.
Optionally, a data frame in which to look for variables with which to predict. If omitted, the fitted linear predictors are used.
The type of prediction required. The default is on the scale of the linear predictors.
The alternative response gives the predicted probabilities.
gives the
gives the
further arguments passed to or from other methods.
Predict Method for lsm Fits